@@ -43,7 +43,9 @@ static Variable variables[] =
   { &sysLocation, getString, NULL, NULL, &sysLocationValue },
   { &sysServices, getInteger, NULL, NULL, &sysServicesValue },
   { &atmfPortIndex, getInteger, NULL, NULL, &atmfPortIndexValue },
+  { &atmfPortMyIdentifier, getInteger, NULL, NULL, &atmfPortIndexValue },
   { &atmfMyIpNmAddress, getIpAddr, NULL, NULL, &atmfMyIpNmAddressValue },
+  { &atmfMySystemIdentifier, getString, NULL, NULL, &atmfMySystemIdentifierValue },
   { &atmfAtmLayerMaxVpiBits, getVpiRange, NULL, NULL, &atmfAtmLayerMaxVpiBitsValue },
   { &atmfAtmLayerMaxVciBits, getVciRange, NULL, NULL, &atmfAtmLayerMaxVciBitsValue },
   { &atmfAtmLayerUniVersion, getInteger, NULL, NULL,
