@@ -1,9 +1,10 @@
 /* common.c - Common functions */
  
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
+#include <stdint.h>
 #include <sys/types.h>
 
 #include "atmd.h"
@@ -18,3 +19,11 @@ void *alloc(size_t size)
     perror("malloc");
     exit(1);
 }
+
+
+uint32_t read_netl(void *p)
+{
+    unsigned char *_p = p;
+
+    return (_p[0] << 24) | (_p[1] << 16) | (_p[2] << 8) | _p[3];
+}
