@@ -1,10 +1,9 @@
 /* sdu2cr.c - Converts SDU sizes and SDU counts to cell counts */
 
-/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1996-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <limits.h>
-#include <linux/atm.h>
 
 #include "atm.h"
 
