@@ -1,6 +1,6 @@
 /* second.c - Phase II, table generation */
 
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-2000 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -180,12 +180,13 @@ static void fields(FIELD *start,int group)
 	    fields(walk->my_block,group);
 	    continue;
 	}
-	if (*walk->id != '_')
+	if (*walk->id != '_') {
 	    if (walk->value && walk->value->type == vt_case)
 		to_c("    { %d, %d, %d, values_%d, %d }, /* %s */\n",group,
 		  walk->pos,walk->size,walk->field,walk->var_len,walk->id);
 	    else to_c("    { %d, %d, %d, NULL, %d }, /* %s */\n",group,
 		  walk->pos,walk->size,walk->var_len,walk->id);
+	}
 	if (walk->value)
 	    switch  (walk->value->type) {
 		case vt_id:
