@@ -141,6 +141,8 @@ Options specific to -t:\n\
 	-C	disable (UDP) checksums\n\
 	-P X	use the specified QOS for the ATM connection. If X is only\n\
 		a number, the following QOS spec is assumed: cbr:pcr=X\n\
+	-S X	use the specified value for the TOS byte. Without -S, the\n\
+		system default is used.\n\
 Options specific to -r:\n\
 	-B	for -s, only output full blocks as specified by -l (for TAR)\n\
 	-T	\"touch\": access each byte as it's read\n\
@@ -182,14 +184,14 @@ char **argv;
 {
     struct timeval td;
     unsigned long addr_tmp;
-    const char *port_name = NULL;
+    const char *port_name = NULL,*tos = NULL;
     int c;
     double mbps;
 int no_check = 0;
 
     if (argc < 2) goto usage;
 
-    while ((c = getopt(argc, argv, "adrstuvBDTb:f:l:n:p:P:A:O:C")) != -1) {
+    while ((c = getopt(argc, argv, "adrstuvBDTb:f:l:n:p:P:S:A:O:C")) != -1) {
 	switch (c) {
 
 	  case 'a':
@@ -233,6 +235,9 @@ int no_check = 0;
 	  case 'P':
 	    qos_spec = optarg;
 	    break;
+	  case 'S':
+	    tos = optarg;
+	    break;
 	  case 'u':
 	    udp = 1;
 	    break;
@@ -505,6 +510,13 @@ int no_check = 0;
 	    }
 	}
     }
+    if (tos) {
+	unsigned char tos_value;
+
+	tos_value = strtoul(tos,NULL,0);
+	if (setsockopt(fd,SOL_IP,IP_TOS,&tos_value,1) < 0)
+	    err("setsockopt IP_TOS");
+    }
 
     errno = 0;
     if (sinkmode) {      
