@@ -59,7 +59,7 @@ static double get_seconds(void) {
   return (double)t.tv_sec+((double)t.tv_usec/(double)1e6);
 }
 
-void main(int argc, char **argv) {
+int main(int argc, char **argv) {
    struct sockaddr_atmpvc addr1, addr2;
    struct atm_qos qos1, qos2;
    char *buffer;
@@ -266,5 +266,5 @@ void main(int argc, char **argv) {
      }
    }
    
-   exit(0);
+   return 0;
 }
